@@ -10,112 +10,69 @@ str.Rcpp_RMLNetwork <- function(object, ...) {
     NULL
 }
 
-# Casting of (a portion of) a multilayer network into an igraph (multi)graph. This is done by creating an intermediate graphml file and loading it as an igraph file
-
-as.igraph.Rcpp_RMLNetwork <- function (x, layers=NULL, merge.actors=TRUE, all.actors=FALSE, ...) {
-    if (is.null(layers)) {
-        layers <- layers_ml(x)
-    }
-    temp_f <- tempfile()
-    write_ml(x, temp_f, format = "graphml", layers, ",", merge.actors, all.actors)
-    g <- read.graph(temp_f, format = "graphml")
-    unlink(temp_f)
-    g
-}
-
-
-# A function to convert the network into a list of igraph objects
-as.list.Rcpp_RMLNetwork <- function(x, ...) {
-    layer.names = sort(layers_ml(x))
-    layers <- vector("list",num_layers_ml(x)+1)
-    layers[[1]] <- as.igraph(x)
-    names(layers)[1] <- "_flat_"
-    if (num_layers_ml(x)>0) {
-        for (i in 1 : num_layers_ml(x)) {
-            layers[[i+1]] <- as.igraph(x,layer.names[i])
-            bad.vs<-V(layers[[i+1]])[degree(layers[[i+1]]) == 0]
-            # remove isolated nodes
-            layers[[i+1]] <-delete.vertices(layers[[i+1]], bad.vs)
-            names(layers)[i+1] <- layer.names[i]
-        }
-    }
-    layers
-}
-
-#
-add_igraph_layer_ml <- function(mlnetwork, g, name)
-{
-    if (is.null(vertex_attr(g)$name))
-    {
-        stop("igraph object must have a vertex attribute 'name' with vertex names")
-    }
-    
-    add_layers_ml(mlnetwork, name, is.directed(g))
-    
-    add_actors_ml(mlnetwork, vertex_attr(g)$name)
-    
-    vertices = data.frame(actor=vertex_attr(g)$name, layer=name)
-    add_vertices_ml(mlnetwork, vertices)
-    
-    for (attr in names(vertex_attr(g)))
-    {
-        if (is.numeric(vertex_attr(g)[[attr]]))
-        {
-            add_attributes_ml(mlnetwork, attributes=attr, type="numeric", target="vertex", layer=name)
-        }
-        if (is.character(vertex_attr(g)[[attr]]))
-        {
-            add_attributes_ml(mlnetwork, attributes=attr, type="string", target="vertex", layer=name)
-        }
-        set_values_ml(mlnetwork, attr, vertices=vertices, values=vertex_attr(g)[[attr]])
-    }
-    
-    
-    edges = data.frame(
-    actor1=get.edgelist(g)[,1], layer1=name,
-    actor2=get.edgelist(g)[,2], layer2=name)
-    
-    add_edges_ml(mlnetwork, edges)
-    
-    for (attr in names(edge_attr(g)))
-    {
-        if (is.numeric(edge_attr(g)[[attr]]))
-        {
-            add_attributes_ml(mlnetwork, attributes=attr, type="numeric", target="edge", layer=name)
-        }
-        if (is.character(edge_attr(g)[[attr]]))
-        {
-            add_attributes_ml(mlnetwork, attributes=attr, type="string", target="edge", layer=name)
-        }
-        set_values_ml(mlnetwork, attr, edges=edges, values=edge_attr(g)[[attr]])
-    }
-}
-
 # Basic layer-by-layer statistics
 summary.Rcpp_RMLNetwork <- function(object, ...) {
     mlnet.layers <- as.list(object)
-    mlnet.table <- as.data.frame(matrix(0,length(mlnet.layers),8))
-    dimnames(mlnet.table) <- list(names(mlnet.layers),c("n","m","dir","nc","dens","cc","apl","dia"))
+    mlnet.table <- as.data.frame(matrix(0,length(mlnet.layers),9))
+    dimnames(mlnet.table) <- list(names(mlnet.layers),c("n","m","dir","nc","slc","dens","cc","apl","dia"))
     if (num_layers_ml(object)>0) {
         for (i in 1 : length(mlnet.layers)) {
             mlnet.table[i,1] = vcount(mlnet.layers[[i]])
             mlnet.table[i,2] = ecount(mlnet.layers[[i]])
             mlnet.table[i,3] = is.directed(mlnet.layers[[i]])
             mlnet.table[i,4] = count_components(mlnet.layers[[i]])
-            mlnet.table[i,5] = graph.density(mlnet.layers[[i]])
-            mlnet.table[i,6] = transitivity(mlnet.layers[[i]])
-            mlnet.table[i,7] = average.path.length(mlnet.layers[[i]])
-            mlnet.table[i,8] = diameter(mlnet.layers[[i]])
+            mlnet.table[i,5] = max(components(mlnet.layers[[i]])$csize)
+            mlnet.table[i,6] = graph.density(mlnet.layers[[i]])
+            mlnet.table[i,7] = transitivity(mlnet.layers[[i]])
+            mlnet.table[i,8] = average.path.length(mlnet.layers[[i]])
+            mlnet.table[i,9] = diameter(mlnet.layers[[i]])
         }
     }
     mlnet.table
 }
 
+#
+
+values2graphics <- function(values, output = "color") {
+    
+    if (!output %in% c("color","shape")) {
+        stop("wrong parameter: output")
+    }
+    
+    if (is.data.frame(values)) {
+        x <- x[[1]]
+    }
+    types <- as.factor(values)
+    num_types <- length(levels(types))
+    color_map = brewer.pal(num_types, "Paired")
+    color_map[types]
+    
+    if ((output == "shape") & num_types>5) {
+        warning("only 5 distinct shapes available: some shapes have been repeated")
+    }
+    
+    l = vector("list")
+    l[["legend.text"]] = levels(types)
+    l[["legend.pch"]] = 21
+    
+    if (output == "color") {
+        l[["legend.col"]] = color_map[1:num_types]
+        l[["color"]] = color_map[types]
+    }
+    
+    if (output == "shape") {
+        l[["legend.pch"]] = ((1:num_types)-1) %% 5 + 21
+        l[["shape"]] = (as.numeric(types)-1) %% 5 + 21
+    }
+    
+    l
+}
+
 # (Rudimentary) plotting function.
     
 plot.Rcpp_RMLNetwork <- function(x,
 layout=NULL, grid=NULL, mai=.1,
-vertex.shape=16, vertex.cex=1, vertex.size=vertex.cex, vertex.color=NULL,
+vertex.shape=21, vertex.cex=1, vertex.size=vertex.cex, vertex.color=NULL,
 vertex.labels=NULL, vertex.labels.pos=3, vertex.labels.offset=.5, vertex.labels.cex=1,
 edge.type=1, edge.width=1, edge.color=1,
 edge.arrow.length=0.1, edge.arrow.angle=20,
@@ -123,6 +80,10 @@ legend.x=NULL, legend.y=NULL, legend.pch=20,
 legend.cex=.5, legend.inset=c(0, 0),
 com=NULL, com.cex=1, ...) {
     
+    if (min(vertex.shape)<21 | max(vertex.shape)>25) {
+        stop("vertex shapes not supported; only values between 21 and 25 allowed")
+    }
+    
     num.cols = num_layers_ml(x)
     num.rows = 1
     if (!is.null(grid)) {
@@ -221,7 +182,7 @@ plot(NA,type="n",xlim=c(x.min,x.min+width*num.cols),ylim=c(y.min,y.min+height*nu
 if (is.null(vertex.color)) {
     vertex.color=layer_palette[layout$z+1]
 }
-points(x_coord(layout),y_coord(layout),pch=vertex.shape,col=vertex.color,cex=vertex.cex)
+points(x_coord(layout),y_coord(layout),pch=vertex.shape,col=vertex.color,cex=vertex.cex,bg=vertex.color)
 
 # draw labels
     if (is.null(vertex.labels)) vertex.labels=layout$actor
